@@ -1,7 +1,7 @@
 
-distsamp <- function(formula, data, 
-    keyfun=c("halfnorm", "exp", "hazard", "uniform"), 
-    output=c("density", "abund"), unitsOut=c("ha", "kmsq"), starts=NULL, 
+distsamp <- function(formula, data,
+    keyfun=c("halfnorm", "exp", "hazard", "uniform"),
+    output=c("density", "abund"), unitsOut=c("ha", "kmsq"), starts=NULL,
     method="BFGS", control=list(), se = TRUE,
     rel.tol=1e-4)
 {
@@ -18,11 +18,11 @@ distsamp <- function(formula, data,
     X.offset <- designMats$X.offset; V.offset <- designMats$V.offset
     if(is.null(X.offset))
         X.offset <- rep(0, nrow(X))
-    if(is.null(V.offset)) 
+    if(is.null(V.offset))
         V.offset <- rep(0, nrow(V))
     M <- nrow(y)
     J <- ncol(y)
-    
+
     u <- a <- matrix(NA, M, J)
     switch(survey,
         line = {
@@ -30,7 +30,7 @@ distsamp <- function(formula, data,
                 a[i,] <- tlength[i] * w
                 u[i,] <- a[i,] / sum(a[i,])
                 }
-            }, 
+            },
         point = {
             for(i in 1:M) {
                 a[i, 1] <- pi*db[2]^2
@@ -39,16 +39,16 @@ distsamp <- function(formula, data,
                 u[i,] <- a[i,] / sum(a[i,])
                 }
             })
-    switch(survey, 
+    switch(survey,
         line = A <- rowSums(a) * 2,
         point = A <- rowSums(a))
-    switch(unitsIn, 
+    switch(unitsIn,
         m = A <- A / 1e6,
         km = A <- A)
-    switch(unitsOut, 
+    switch(unitsOut,
         ha = A <- A * 100,
         kmsq = A <- A)
-        
+
     lamParms <- colnames(X)
     detParms <- colnames(V)
     nAP <- length(lamParms)
@@ -56,12 +56,12 @@ distsamp <- function(formula, data,
     nP <- nAP + nDP
     cp <- matrix(NA, M, J)
     switch(keyfun,
-    halfnorm = { 
+    halfnorm = {
         altdetParms <- paste("sigma", colnames(V), sep="")
         if(is.null(starts)) {
             starts <- c(rep(0, nAP), log(max(db)), rep(0, nDP-1))
             names(starts) <- c(lamParms, detParms)
-            } 
+            }
         else
             if(is.null(names(starts))) names(starts) <- c(lamParms, detParms)
         nll <- function(param) {
@@ -70,27 +70,22 @@ distsamp <- function(formula, data,
             if(identical(output, "density"))
                 lambda <- lambda * A
             for(i in 1:M) {
-                switch(survey, 
-                line = { 
+                switch(survey,
+                line = {
                     f.0 <- 2 * dnorm(0, 0, sd=sigma[i])
-                    int <- 2 * (pnorm(db[-1], 0, sd=sigma[i]) - 
+                    int <- 2 * (pnorm(db[-1], 0, sd=sigma[i]) -
                         pnorm(db[-(J+1)], 0, sd=sigma[i]))
-                    cp[i,] <- int / f.0 / w 
+                    cp[i,] <- int / f.0 / w
                     },
                 point = {
                     for(j in 1:J) {
-                        int <- integrate(grhn, db[j], db[j+1], sigma=sigma[i], 
+                        int <- integrate(grhn, db[j], db[j+1], sigma=sigma[i],
                             stop.on.error=FALSE)
                         mess <- int$message
                         if(identical(mess, "OK"))
                             cp[i, j] <- int$value * 2*pi / a[i,j]
                         else {
-                            warning(paste("integrate() failed with warning", 
-                                mess, "an approximation was used instead"))
-                            increment <- (db[j+1] - db[j]) / 100
-                            int <- sum(grhn(seq(db[j], db[j+1], by=increment), 
-                                sigma=sigma[i]) * increment)
-                            cp[i, j] <- int * 2*pi / a[i, j]
+                            cp[i, j] <- NA
                             }
                         }
                     })
@@ -99,12 +94,12 @@ distsamp <- function(formula, data,
             ll <- dpois(y, lambda * cp, log=TRUE)
             -sum(ll)
             }},
-    exp = { 
+    exp = {
         altdetParms <- paste("rate", colnames(V), sep="")
         if(is.null(starts)) {
             starts <- c(rep(0, nAP), 0, rep(0, nDP-1))
             names(starts) <- c(lamParms, detParms)
-            } 
+            }
         else
             if(is.null(names(starts))) names(starts) <- c(lamParms, detParms)
         nll <- function(param) {
@@ -113,55 +108,45 @@ distsamp <- function(formula, data,
             if(identical(output, "density"))
                 lambda <- lambda * A
             for(i in 1:M) {
-                switch(survey, 
+                switch(survey,
                 line = {
                     for(j in 1:J) {
-                        int <- integrate(gxexp, db[j], db[j+1], rate=rate[i], 
+                        int <- integrate(gxexp, db[j], db[j+1], rate=rate[i],
                             stop.on.error=FALSE)
                         mess <- int$message
                         if(identical(mess, "OK"))
                             cp[i, j] <- int$value / w[j]
                         else {
-                            warning(paste("integrate() failed with warning", 
-                                mess, "an approximation was used instead"))
-                            increment <- (db[j+1] - db[j]) / 100
-                            int <- sum(gxexp(seq(db[j], db[j+1], by=increment), 
-                                rate=rate[i]) * increment)
-                            cp[i, j] <- int / w[j]
+                            cp[i, j] <- NA
                             }
                         }},
                 point = {
                     for(j in 1:J) {
-                        int <- integrate(grexp, db[j], db[j+1], rate=rate[i], 
+                        int <- integrate(grexp, db[j], db[j+1], rate=rate[i],
                             stop.on.error=FALSE)
                         mess <- int$message
                         if(identical(mess, "OK"))
                             cp[i, j] <- int$value * 2*pi / a[i,j]
                         else {
-                            warning(paste("integrate() failed with warning", 
-                                mess, "an approximation was used instead"))
-                            increment <- (db[j+1] - db[j]) / 100
-                            int <- sum(grexp(seq(db[j], db[j+1], by=increment), 
-                                rate=rate[i]) * increment)
-                            cp[i, j] <- int * 2*pi / a[i, j]
+                            cp[i, j] <- NA
                             }
-                        }	
+                        }
                     })
                 cp[i,] <- cp[i,] * u[i,]
                 }
             ll <- dpois(y, lambda * cp, log=TRUE)
             -sum(ll)
             }},
-    hazard = {	
+    hazard = {
         nDP <- length(detParms)
         nP <- nAP + nDP + 1
         altdetParms <- paste("shape", colnames(V), sep="")
         if(is.null(starts)) {
             starts <- c(rep(0, nAP), log(median(db)), rep(0, nDP-1), 1)
             names(starts) <- c(lamParms, detParms, "scale")
-            } 
+            }
         else
-            if(is.null(names(starts))) 
+            if(is.null(names(starts)))
                 names(starts) <- c(lamParms, detParms, "scale")
         nll <- function(param) {
             shape <- drop(exp(V %*% param[(nAP+1):(nP-1)] + V.offset))
@@ -170,54 +155,44 @@ distsamp <- function(formula, data,
             if(identical(output, "density"))
                 lambda <- lambda * A
             for(i in 1:M) {
-                switch(survey, 
+                switch(survey,
                 line = {
                     for(j in 1:J) {
-                        int <- integrate(gxhaz, db[j], db[j+1], shape=shape[i], 
+                        int <- integrate(gxhaz, db[j], db[j+1], shape=shape[i],
                             scale=scale, stop.on.error=FALSE)
                         mess <- int$message
                         if(identical(mess, "OK"))
                             cp[i, j] <- int$value / w[j]
                         else {
-                            warning(paste("integrate() failed with warning", 
-                                mess, "an approximation was used instead"))
-                            increment <- (db[j+1] - db[j]) / 100
-                            int <- sum(gxhaz(seq(db[j], db[j+1], by=increment), 
-                                shape=shape[i], scale=scale) * increment)
-                            cp[i, j] <- int / w[j]
+                            cp[i, j] <- NA
                             }
                         }},
-                point = {   
+                point = {
                     for(j in 1:J) {
-                        int <- integrate(grhaz, db[j], db[j+1], shape=shape[i], 
+                        int <- integrate(grhaz, db[j], db[j+1], shape=shape[i],
                             scale=scale, stop.on.error=FALSE)
                         mess <- int$message
                         if(identical(mess, "OK"))
                             cp[i, j] <- int$value * 2*pi / a[i,j]
                         else {
-                            warning(paste("integrate() failed with warning", 
-                                mess, "an approximation was used instead"))
-                            increment <- (db[j+1] - db[j]) / 100
-                            int <- sum(grhaz(seq(db[j], db[j+1], by=increment), 
-                                shape=shape[i], scale=scale) * increment)
-                            cp[i, j] <- int * 2*pi / a[i, j]
+                            cp[i, j] <- NA
                             }
-                        }	
+                        }
 
                     })
                 cp[i,] <- cp[i,] * u[i,]
                 }
             ll <- dpois(y, lambda * cp, log=TRUE)
             -sum(ll)
-            }}, 
+            }},
     uniform = {
         detParms <- character(0)
         altdetParms <- character(0)
-        nDP <- 0	
+        nDP <- 0
         if(is.null(starts)) {
             starts <- rep(0, length(lamParms))
             names(starts) <- lamParms
-            } 
+            }
         else
             if(is.null(names(starts))) names(starts) <- lamParms
         nll <- function(param) {
@@ -232,13 +207,13 @@ distsamp <- function(formula, data,
     opt <- fm
     ests <- fm$par
     if(se) {
-        covMat <- tryCatch(solve(fm$hessian), error=function(x) 
+        covMat <- tryCatch(solve(fm$hessian), error=function(x)
         stop(simpleError("Hessian is singular. Try using fewer covariates or providing starting values.")))
         if(class(covMat)[1] == "simpleError") {
             print(covMat$message)
             covMat <- matrix(NA, nP, nP)
-            } 
-        } 
+            }
+        }
     else
         covMat <- matrix(NA, nP, nP)
     estsAP <- ests[1:nAP]
@@ -246,7 +221,7 @@ distsamp <- function(formula, data,
         estsDP <- ests[(nAP+1):(nP-1)]
         estsScale <- ests[nP]
         }
-    else 
+    else
         estsDP <- ests[(nAP+1):nP]
     covMatAP <- covMat[1:nAP, 1:nAP, drop=F]
     if(keyfun=="hazard") {
@@ -255,33 +230,33 @@ distsamp <- function(formula, data,
         }
     else if(keyfun!="uniform")
         covMatDP <- covMat[(nAP+1):nP, (nAP+1):nP, drop=F]
-    names(estsDP) <- altdetParms 
+    names(estsDP) <- altdetParms
     fmAIC <- 2 * fm$value + 2 * nP
     stateName <- switch(output, abund = "Abundance", density = "Density")
-    stateEstimates <- unmarkedEstimate(name = stateName, 
-        short.name = "lam", estimates = estsAP, covMat = covMatAP, 
+    stateEstimates <- unmarkedEstimate(name = stateName,
+        short.name = "lam", estimates = estsAP, covMat = covMatAP,
         invlink = "exp", invlinkGrad = "exp")
     if(keyfun != "uniform") {
-        detEstimates <- unmarkedEstimate(name = "Detection", short.name = "p", 
-        estimates = estsDP, covMat = covMatDP, invlink = "exp", 
+        detEstimates <- unmarkedEstimate(name = "Detection", short.name = "p",
+        estimates = estsDP, covMat = covMatDP, invlink = "exp",
         invlinkGrad = "exp")
         if(keyfun != "hazard")
             estimateList <- unmarked:::unmarkedEstimateList(list(
                 state=stateEstimates, det=detEstimates))
         else {
-            scaleEstimates <- unmarkedEstimate(name = "Hazard-rate(scale)", 
-                short.name = "p", estimates = estsScale, 
+            scaleEstimates <- unmarkedEstimate(name = "Hazard-rate(scale)",
+                short.name = "p", estimates = estsScale,
                 covMat = covMatScale, invlink = "exp", invlinkGrad = "exp")
-            estimateList <- unmarked:::unmarkedEstimateList(list(state=stateEstimates, 
+            estimateList <- unmarked:::unmarkedEstimateList(list(state=stateEstimates,
                 det=detEstimates, scale=scaleEstimates))
-            }			
-        } 
+            }
+        }
     else
         estimateList <- unmarked:::unmarkedEstimateList(list(state=stateEstimates))
-    dsfit <- new("unmarkedFitDS", fitType = "distsamp", call = match.call(), 
-        opt = opt, formula = formula, data = data, keyfun=keyfun, 
-        sitesRemoved = designMats$removed.sites, unitsOut=unitsOut, 
-        estimates = estimateList, AIC = fmAIC, negLogLike = fm$value, 
+    dsfit <- new("unmarkedFitDS", fitType = "distsamp", call = match.call(),
+        opt = opt, formula = formula, data = data, keyfun=keyfun,
+        sitesRemoved = designMats$removed.sites, unitsOut=unitsOut,
+        estimates = estimateList, AIC = fmAIC, negLogLike = fm$value,
         nllFun = nll, output=output)
     return(dsfit)
 }
@@ -290,25 +265,25 @@ distsamp <- function(formula, data,
 # Detection functions
 
 gxhn <- function(x, sigma) exp(-x^2/(2 * sigma^2))
-gxexp <- function(x, rate) exp(-x / rate) 
+gxexp <- function(x, rate) exp(-x / rate)
 gxhaz <- function(x, shape, scale)  1 - exp(-(x/shape)^-scale)
 grhn <- function(r, sigma) exp(-r^2/(2 * sigma^2)) * r
 grexp <- function(r, rate) exp(-r / rate) * r
 grhaz <- function(r, shape, scale)  (1 - exp(-(r/shape)^-scale)) * r
 
-dxhn <- function(x, sigma) 
+dxhn <- function(x, sigma)
 	gxhn(x=x, sigma=sigma) / integrate(gxhn, 0, Inf, sigma=sigma)$value
-drhn <- function(r, sigma) 
+drhn <- function(r, sigma)
 	grhn(r=r, sigma=sigma) / integrate(grhn, 0, Inf, sigma=sigma)$value
-dxexp <- function(x, rate) 
+dxexp <- function(x, rate)
 	gxexp(x=x, rate=rate) / integrate(gxexp, 0, Inf, rate=rate)$value
-drexp <- function(r, rate) 
+drexp <- function(r, rate)
 	grexp(r=r, rate=rate) / integrate(grexp, 0, Inf, rate=rate)$value
 dxhaz <- function(x, shape, scale)
-	gxhaz(x=x, shape=shape, scale=scale) / integrate(gxhaz, 0, Inf, 
+	gxhaz(x=x, shape=shape, scale=scale) / integrate(gxhaz, 0, Inf,
 		shape=shape, scale=scale)$value
 drhaz <- function(r, shape, scale)
-	grhaz(r=r, shape=shape, scale=scale) / integrate(grhaz, 0, Inf, 
+	grhaz(r=r, shape=shape, scale=scale) / integrate(grhaz, 0, Inf,
 		shape=shape, scale=scale)$value
 
 
