@@ -508,7 +508,7 @@ setMethod("handleNA", "unmarkedFramePCO",
 # UnmarkedFrameGMN    
 	
 
-setMethod("getDesign", "unmarkedFrameGMM", 
+setMethod("getDesign", "unmarkedFrameG3", 
     function(umf, formula, na.rm = TRUE) 
 {
     ac1 <- as.character(formula)
@@ -586,7 +586,7 @@ setMethod("getDesign", "unmarkedFrameGMM",
 
 
 
-setMethod("handleNA", "unmarkedFrameGMM", 
+setMethod("handleNA", "unmarkedFrameG3", 
     function(umf, Xlam, Xlam.offset, Xphi, Xphi.offset, Xdet, Xdet.offset) 
 {
 
