@@ -24,7 +24,8 @@ test.distsamp.covs <- function() {
 
 
 
-test.distsamp.line.keyfuns <- function() {
+test.distsamp.line.keyfuns <- function() 
+{
     y <- structure(c(7, 7, 12, 9, 9, 11, 9, 5, 7, 6, 25, 26, 30, 26, 23, 
         24, 20, 33, 26, 32, 5, 3, 8, 7, 1, 4, 4, 7, 7, 6, 3, 1, 1, 4, 
         4, 4, 3, 6, 2, 3), .Dim = c(10L, 4L))
@@ -57,11 +58,17 @@ test.distsamp.line.keyfuns <- function() {
     checkEqualsNumeric(SE(Sh), 5.099981, tol=1e-4)
     checkEqualsNumeric(coef(Sc), 0.8315524, tol=1e-4)
     checkEqualsNumeric(SE(Sc), 0.4753275, tol=1e-4)
+
+    fm.unif <- distsamp(~1~1, umf, keyfun="uniform")
+    D <- backTransform(fm.unif, type="state") 
+    checkEqualsNumeric(coef(D), 107.5000, tol=1e-4)        
         
-    }
+}
+  
     
     
-test.distsamp.point.keyfuns <- function() {
+test.distsamp.point.keyfuns <- function() 
+{
     y <- structure(c(1, 0, 0, 0, 0, 0, 3, 1, 1, 0, 16, 15, 18, 14, 22, 
         24, 12, 20, 20, 21, 10, 9, 9, 5, 6, 6, 6, 9, 5, 6, 6, 6, 4, 2, 
         6, 3, 3, 3, 1, 4), .Dim = c(10L, 4L))
@@ -77,11 +84,11 @@ test.distsamp.point.keyfuns <- function() {
     checkEqualsNumeric(coef(S), 18.05958, tol=1e-4)
     checkEqualsNumeric(SE(S), 3.341798, tol=1e-4)
 
-    fm.exp <- distsamp(~1~1, umf, keyfun="exp", starts=c(6, 3))
+    fm.exp <- distsamp(~1~1, umf, keyfun="exp", starts=c(6, 0))
     D <- backTransform(fm.exp, type="state") 
     S <- backTransform(fm.exp, type="det")
     checkEqualsNumeric(coef(D), 369.7526, tol=1e-4)
-    checkEqualsNumeric(SE(D), 68.12803, tol=1e-4)
+    checkEqualsNumeric(SE(D), 68.11901, tol=1e-4)
     checkEqualsNumeric(coef(S), 28.90848, tol=1e-4)
     checkEqualsNumeric(SE(S), 11.66219, tol=1e-4)
 
@@ -95,7 +102,11 @@ test.distsamp.point.keyfuns <- function() {
     checkEqualsNumeric(SE(Sh), 0.8950444, tol=1e-4)
     checkEqualsNumeric(coef(Sc), 5.797366, tol=1e-4)
     checkEqualsNumeric(SE(Sc), 4.054381, tol=1e-4)
+
+    fm.unif <- distsamp(~1~1, umf, keyfun="uniform")
+    D <- backTransform(fm.unif, type="state") 
+    checkEqualsNumeric(coef(D), 236.3451, tol=1e-4)        
         
-    }    
+}    
         
     
\ No newline at end of file
